(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 12.1' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       158,          7]
NotebookDataLength[     30158,        751]
NotebookOptionsPosition[     26079,        684]
NotebookOutlinePosition[     26635,        705]
CellTagsIndexPosition[     26592,        702]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{
Cell["Chapter 5, Section 5.4, Figure 5.11", "Section",ExpressionUUID->"323a7a94-74ae-47fe-bf70-03175e2b4562"],

Cell["Create a graphics object to denote the Sun.", "Text",
 CellFrame->True,
 Background->GrayLevel[
  0.849989],ExpressionUUID->"edf2fbdf-9d4b-4a22-8970-49a68d5ae8b9"],

Cell["sun=Graphics[{PointSize[0.05],Point[{0,0}]}];", "Input",
 CellChangeTimes->{3.811323110125649*^9},
 AspectRatioFixed->False,
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"In[1]:=",ExpressionUUID->"4bb167c8-34fc-47f4-b925-f9541dac110a"],

Cell[TextData[{
 "We use the same functions, ",
 StyleBox["ksolve", "Input"],
 " and ",
 StyleBox["position", "Input"],
 ", as we used in ",
 StyleBox["Fig.5.9.nb",
  FontWeight->"Bold"],
 " and ",
 StyleBox["Fig.5.10a.nb",
  FontWeight->"Bold"],
 " to solve Kepler's equations and find the position vector as a function of \
mean anomaly."
}], "Text",
 CellFrame->True,
 Background->GrayLevel[
  0.849989],ExpressionUUID->"68683205-1ab7-4cc9-b22b-f479724cb4e4"],

Cell["ksolve[ma_,e_]:=FindRoot[ea - e Sin[ea] == ma, {ea,ma}];", "Input",
 AspectRatioFixed->False,
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"In[2]:=",ExpressionUUID->"d1686b74-31ec-40e4-83b2-fbc8229bce7f"],

Cell["\<\
position[ma_,a_,e_]:=
(eca=ea/.ksolve[ma,e];
x=N[a(Cos[eca]-e)]; y=N[a Sqrt[1-e^2] Sin[eca]];
{x,y})\
\>", "Input",
 AspectRatioFixed->False,
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"In[3]:=",ExpressionUUID->"93ff1937-30ca-4c36-9971-37e5d62339b4"],

Cell[TextData[{
 "We will use a list, ",
 StyleBox["rotlist", "Input"],
 ", to store the points we calculate.  First we must set it to be empty."
}], "Text",
 CellFrame->True,
 Background->GrayLevel[
  0.849989],ExpressionUUID->"3833d889-e0a5-48d1-9805-10d9d811979d"],

Cell["rotlist={};", "Input",
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"In[4]:=",ExpressionUUID->"03983051-090a-40f2-a095-6721e57f302b"],

Cell[TextData[{
 "We are interested in the ",
 StyleBox["p", "Input"],
 " = 1/2 resonance with unit semi-major axis and an eccentricity, ",
 StyleBox["e", "Input"],
 " = 0.45."
}], "Text",
 CellFrame->True,
 Background->GrayLevel[
  0.849989],ExpressionUUID->"a3925c35-3aee-4f0e-aedf-fe61a58b9384"],

Cell["p=1/2; a=1.0; e=0.45;", "Input",
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"In[5]:=",ExpressionUUID->"f0f007a0-3ea4-45bf-909d-ebc2a91aa0f8"],

Cell[TextData[{
 "Set up a loop to calculate and add points (positions at equal time \
intervals) to ",
 StyleBox["rotlist", "Input"],
 ".  Note that we have to go round the orbit twice."
}], "Text",
 CellFrame->True,
 Background->GrayLevel[
  0.849989],ExpressionUUID->"3c78e65f-97f1-4cc7-b96d-9f75161d5094"],

Cell["\<\
Do[
(posvec=position[t,a,e];
f=N[ArcTan[posvec[[1]],posvec[[2]]]];
rad=N[Sqrt[posvec[[1]]^2+posvec[[2]]^2]];
\[Theta]=p*t;
\[Psi]=\[Theta]-f;
blip=N[{rad*Cos[\[Psi]],rad*Sin[\[Psi]]}];
AppendTo[rotlist,blip];),
{t,0,4Pi,Pi/10}]\
\>", "Input",
 AspectRatioFixed->False,
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"In[6]:=",ExpressionUUID->"5a5f813c-a547-4e6f-b415-76a71e2b210c"],

Cell["Plot the resulting points.", "Text",
 CellFrame->True,
 Background->GrayLevel[
  0.849989],ExpressionUUID->"8414c6b9-3e43-460b-9c16-2783dba83253"],

Cell[CellGroupData[{

Cell["\<\
points=
ListPlot[rotlist,AspectRatio->Automatic, 
PlotStyle->PointSize[0.05],Axes->None]\
\>", "Input",
 CellChangeTimes->{{3.811323149381435*^9, 3.811323151632004*^9}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"In[7]:=",ExpressionUUID->"d1fad859-b08d-4a65-8f64-0da2a7427869"],

Cell[BoxData[
 GraphicsBox[{{}, 
   {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.05], 
    AbsoluteThickness[1.6], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQBGIQPWsmCDy0Z4CCGd5aV4+r3LN3Pvvr15nsm/t9LE7w
/vtx2f5bkastr8Gz/Z+iBas4jh+xv/xqW7T3/Tf7r6lMTfnWvtL+nEZt+4q3
H/Z/PJK370LX9P2R3+5LrXn4ab9/+GLRcOv1+w8E9b+Wzv+y/0F9kPwFiU37
M0PnTeRZ/HX/8pBZz25YrNuvGKl1I6/h2/5wK7P1Hz4s2L9WIuBBGNv3/ddf
O/8NmD7TxhgMvu+fDZG3Xw+VN4Pot1eC6mdoAJtvnwU1vxdiv/1BqP0nIO6z
h7kvCeL+/eeh7n8J8d/+K1D/Qf2//wfU/1Mh4bPfGxo+0PDb/zfN75R53co9
06HyLhB5e0+o/t8Q/fa/oeafh5hvfxBq/1mI/fabj6K4zz4d1f32Eqj+s0+D
+h8afvbnUMPHfsfWLmFPhiN7oOFn3wQNX5i8DGr423+Fxk821PzzYZD42w+1
/zzEffujoe77jRr/9pwxkPRxEeo/F2j6gfm/G5q+YqDhA0t/kPDbaQMAag9j
tw==
     "]]}, {{}, {}}},
  Axes->{False, False},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  Method->{
   "OptimizePlotMarkers" -> True, "OptimizePlotMarkers" -> True, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        Identity[
         Part[#, 1]], 
        Identity[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        Identity[
         Part[#, 1]], 
        Identity[
         Part[#, 2]]}& )}},
  PlotRange->{{-0.55, 0.55}, {-1.45, 1.45}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{{3.811323144700674*^9, 3.811323153626288*^9}, 
   3.811323290644177*^9},
 CellLabel->"Out[7]=",ExpressionUUID->"4a6151f4-33f5-42b3-9286-5df929df066f"]
}, Open  ]],

Cell[TextData[{
 "Now go through the same procedure again but with more points in order to \
plot the path in the rotating frame.  First set the contents of ",
 StyleBox["rotlist", "Input"],
 " to be empty."
}], "Text",
 CellFrame->True,
 Background->GrayLevel[
  0.849989],ExpressionUUID->"e8545e6a-1627-4e25-bf3a-728cf926a47c"],

Cell["rotlist = {};", "Input",
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"In[8]:=",ExpressionUUID->"36a73641-7856-4644-8d7c-81278919c504"],

Cell["Create the points in a loop ...", "Text",
 CellFrame->True,
 Background->GrayLevel[
  0.849989],ExpressionUUID->"760c4a33-de0e-44f3-9c41-d2b753070faf"],

Cell["\<\
Do[
(posvec=position[t,a,e];
f=N[ArcTan[posvec[[1]],posvec[[2]]]];
rad=N[Sqrt[posvec[[1]]^2+posvec[[2]]^2]];
\[Theta]=p*t;
\[Psi]=\[Theta]-f;
blip=N[{rad*Cos[\[Psi]],rad*Sin[\[Psi]]}];
AppendTo[rotlist,blip];),
{t,0,4Pi,Pi/40}]\
\>", "Input",
 AspectRatioFixed->False,
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"In[9]:=",ExpressionUUID->"721b9631-d25d-486a-9edc-406ce1e0f04c"],

Cell["... and plot them.", "Text",
 CellFrame->True,
 Background->GrayLevel[
  0.849989],ExpressionUUID->"31c476c0-5976-4e30-b16c-1573820c02a3"],

Cell[CellGroupData[{

Cell["\<\
curve =
ListPlot[rotlist,PlotJoined->True,
 AspectRatio->Automatic, Axes->None]\
\>", "Input",
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"In[10]:=",ExpressionUUID->"1172eeff-6f38-4a63-9403-43d4f496defa"],

Cell[BoxData[
 GraphicsBox[{{}, {{}, {}, 
    {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.009166666666666668], 
     AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJxVlntUTXkUx++UqXmUx2iIWJUyrJY8xiMiu5LVagx6UBopQialRpjGrEHG
H81iDGm1EmYmjxKRyms02FwRUTcylVfdiJFCqW64as24+3v+OGetu+4fZ51z
9u+7v9/P3o6R8YFLzTQazd7/f+//d2W8v+pJg2v76VOelrH19OZyXf617iK+
mXmi4cW/eoqYpu/ddaCUU5u1/toBekr4xNJRm1rJO2e4/FPiXEvTyt6+vRFz
h7Xe3RH2Jfeov/2ARIuKWnY1b92R636HVu66bGelr+fjIWm3ajKqKPtShZu9
YwN/PfGqdffrSjIkTPewHv2EXd/2fvzhspvkH/PTQo/PnvKpn5cHPb1fRjNT
m+eZlTVy9KOKJbdHXCPbRScdvJY28av5fX78qKSYKp+dmj+jrpmLzINdehVc
oNHjxwRVT33BWUXXJqXfO0OLfF8HWSa/ZKf2smer3xXS4xMPzaYsaOEq57Ql
huRDVD58XXLO8xbWTa4t6nF+Dw1dsf/64TWt3KfBptmiZiMFb3PTvulo5fYF
sVU27Ul8NGJc0vD4V9xaHHe+YnM6hxrqBh6pf8WxTV55CaP2ccQV7zz9zDb+
4EGXmd0vB3n2nQ37rE+0sblxX3bF/Vwe7ODpF23TzrND9n8eMvkYXwjc1mQX
385+q26EVtXkc8SjL8O9i9s54Ln7n++yC/j7rNxRLX07uPGW/oFnr0Jeq3FP
GhPewfoNgfYVtoUcPfePFKv9HfzUbadrXWkBezmaDdz0sIM13d2nc0YUcHHj
usWpgwwc7UH9YqfnsyHfwnNSgIEPztn1pGZiHjuGutTEJRk4pi45Qb8yl+Ne
3g11PWzgc/bjfTf65LDH+tQtK8oN7NuzpDSQD7DFp3N9hz83cIj7hGMtLZl8
1NZfH2zRybql32a26zLYunHDmrYBncw7gmyco1I4xct87JthnZyctccuYdNG
bjCmbVoyupOrm6Z1+adnTBlrujr5rtwn5X5liul5Up4vjDK9n5T375bv0zF8
P0zqI6W+LKmflPqHyvloBc43Qc5PQ3D+1aIPKfo4in6k6HdV9CVvRd8kk/60
HPq3SX9I6Y+v9I8S0b850l9ahP5ulf7TRfR/qviDFH803zf5h/zhn3XiL1L8
dVX8R4r/3MJN/qQ8+NPrkcm/rPj3uPibh8HfkeJ/1sH/xjZTPljJx3eSH45E
fs5Jvngk8tUo+ePbyF+c5JOVfOZIfjkQ+R0i+ea5yDfyz6+R/zzhAx8BH5yE
H5wIfpwTvrAT+JIm/OEZ4A/4xCvBpyrhF/cAv8A3LgbfwD/uippV6rb+0Fnl
fpHcp1t43kGeJ+X9a+X9lI7v+8j36Szqc5D6aCTqj5f66STOd0DOR344v1HO
TyOgT4DoQ9eh31eiH62Cvv1FXzJCf53oT0p/wD/6Hf0D/8hF+McN0l+6iP6X
Sf/JzEP84ST+IC38EyL+oULhH4F/dPyyyn/0DfwZLv6kfsI/miX+pcHwt734
m5ap/U/LkY+Fkg8KQ37WSH6oFvlKlHyRrTp/VId8gn9U1yX51Up+KQL57pB8
UxTyD/6RsVbFB6pW84O2qflC5Wr+ULbwj6yET9Qq/KPtwi86mK3iG/11cnNf
P03xWfCPVqv5SJkpKn5STzVf6WfwV/m+D/hsifp+Bb+non4rNd9pkJr/FIX5
oOhjg/lxCfr9jfkC/lEH5k8M9H+C+fQD+uOunl+kzLdI9FcXLPOP0X9XzEdH
+KNa+McB8E/5M9V8JZ34j+fDf+MWynwG/yhV/Euh8O9tzHdn+Nuonv80HfuB
ko+12B8WIz/Z2C/GIV8fh8n+cRP5m4f9ZBDyuRP7Swjy64z9Zg7y7YP9R8n/
eexHe8EHF+xPCeDHaexXLuDLFuxfYeDPVuxnu8GnSuxvX4Bfv2G/C78ifFP2
P+HfmSn/ATVsZwQ=
      "]]}}, {{}, {}}},
  Axes->{False, False},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  Method->{
   "OptimizePlotMarkers" -> True, "OptimizePlotMarkers" -> True, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        Identity[
         Part[#, 1]], 
        Identity[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        Identity[
         Part[#, 1]], 
        Identity[
         Part[#, 2]]}& )}},
  PlotRange->{{-0.55, 0.55}, {-1.45, 1.45}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.811323167726729*^9, 3.811323291004415*^9},
 CellLabel->"Out[10]=",ExpressionUUID->"9692a423-16f7-46e1-8869-ceaf9c98fbd3"]
}, Open  ]],

Cell["Finally, display the points and the curve on the same plot.", "Text",
 CellFrame->True,
 Background->GrayLevel[
  0.849989],ExpressionUUID->"ee164c14-36fd-49b1-80a6-3cd912011d8b"],

Cell[CellGroupData[{

Cell["Show[points,curve,sun]", "Input",
 CellChangeTimes->{3.811323174350851*^9},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"In[11]:=",ExpressionUUID->"d52923cb-3730-4958-9696-93bd3884208a"],

Cell[BoxData[
 GraphicsBox[{{{}, 
    {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.05], 
     AbsoluteThickness[1.6], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQBGIQPWsmCDy0Z4CCGd5aV4+r3LN3Pvvr15nsm/t9LE7w
/vtx2f5bkastr8Gz/Z+iBas4jh+xv/xqW7T3/Tf7r6lMTfnWvtL+nEZt+4q3
H/Z/PJK370LX9P2R3+5LrXn4ab9/+GLRcOv1+w8E9b+Wzv+y/0F9kPwFiU37
M0PnTeRZ/HX/8pBZz25YrNuvGKl1I6/h2/5wK7P1Hz4s2L9WIuBBGNv3/ddf
O/8NmD7TxhgMvu+fDZG3Xw+VN4Pot1eC6mdoAJtvnwU1vxdiv/1BqP0nIO6z
h7kvCeL+/eeh7n8J8d/+K1D/Qf2//wfU/1Mh4bPfGxo+0PDb/zfN75R53co9
06HyLhB5e0+o/t8Q/fa/oeafh5hvfxBq/1mI/fabj6K4zz4d1f32Eqj+s0+D
+h8afvbnUMPHfsfWLmFPhiN7oOFn3wQNX5i8DGr423+Fxk821PzzYZD42w+1
/zzEffujoe77jRr/9pwxkPRxEeo/F2j6gfm/G5q+YqDhA0t/kPDbaQMAag9j
tw==
      "]]}, {{}, {}}}, {{}, {{}, {}, 
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.009166666666666668],
       AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJxVlntUTXkUx++UqXmUx2iIWJUyrJY8xiMiu5LVagx6UBopQialRpjGrEHG
H81iDGm1EmYmjxKRyms02FwRUTcylVfdiJFCqW64as24+3v+OGetu+4fZ51z
9u+7v9/P3o6R8YFLzTQazd7/f+//d2W8v+pJg2v76VOelrH19OZyXf617iK+
mXmi4cW/eoqYpu/ddaCUU5u1/toBekr4xNJRm1rJO2e4/FPiXEvTyt6+vRFz
h7Xe3RH2Jfeov/2ARIuKWnY1b92R636HVu66bGelr+fjIWm3ajKqKPtShZu9
YwN/PfGqdffrSjIkTPewHv2EXd/2fvzhspvkH/PTQo/PnvKpn5cHPb1fRjNT
m+eZlTVy9KOKJbdHXCPbRScdvJY28av5fX78qKSYKp+dmj+jrpmLzINdehVc
oNHjxwRVT33BWUXXJqXfO0OLfF8HWSa/ZKf2smer3xXS4xMPzaYsaOEq57Ql
huRDVD58XXLO8xbWTa4t6nF+Dw1dsf/64TWt3KfBptmiZiMFb3PTvulo5fYF
sVU27Ul8NGJc0vD4V9xaHHe+YnM6hxrqBh6pf8WxTV55CaP2ccQV7zz9zDb+
4EGXmd0vB3n2nQ37rE+0sblxX3bF/Vwe7ODpF23TzrND9n8eMvkYXwjc1mQX
385+q26EVtXkc8SjL8O9i9s54Ln7n++yC/j7rNxRLX07uPGW/oFnr0Jeq3FP
GhPewfoNgfYVtoUcPfePFKv9HfzUbadrXWkBezmaDdz0sIM13d2nc0YUcHHj
usWpgwwc7UH9YqfnsyHfwnNSgIEPztn1pGZiHjuGutTEJRk4pi45Qb8yl+Ne
3g11PWzgc/bjfTf65LDH+tQtK8oN7NuzpDSQD7DFp3N9hz83cIj7hGMtLZl8
1NZfH2zRybql32a26zLYunHDmrYBncw7gmyco1I4xct87JthnZyctccuYdNG
bjCmbVoyupOrm6Z1+adnTBlrujr5rtwn5X5liul5Up4vjDK9n5T375bv0zF8
P0zqI6W+LKmflPqHyvloBc43Qc5PQ3D+1aIPKfo4in6k6HdV9CVvRd8kk/60
HPq3SX9I6Y+v9I8S0b850l9ahP5ulf7TRfR/qviDFH803zf5h/zhn3XiL1L8
dVX8R4r/3MJN/qQ8+NPrkcm/rPj3uPibh8HfkeJ/1sH/xjZTPljJx3eSH45E
fs5Jvngk8tUo+ePbyF+c5JOVfOZIfjkQ+R0i+ea5yDfyz6+R/zzhAx8BH5yE
H5wIfpwTvrAT+JIm/OEZ4A/4xCvBpyrhF/cAv8A3LgbfwD/uippV6rb+0Fnl
fpHcp1t43kGeJ+X9a+X9lI7v+8j36Szqc5D6aCTqj5f66STOd0DOR344v1HO
TyOgT4DoQ9eh31eiH62Cvv1FXzJCf53oT0p/wD/6Hf0D/8hF+McN0l+6iP6X
Sf/JzEP84ST+IC38EyL+oULhH4F/dPyyyn/0DfwZLv6kfsI/miX+pcHwt734
m5ap/U/LkY+Fkg8KQ37WSH6oFvlKlHyRrTp/VId8gn9U1yX51Up+KQL57pB8
UxTyD/6RsVbFB6pW84O2qflC5Wr+ULbwj6yET9Qq/KPtwi86mK3iG/11cnNf
P03xWfCPVqv5SJkpKn5STzVf6WfwV/m+D/hsifp+Bb+non4rNd9pkJr/FIX5
oOhjg/lxCfr9jfkC/lEH5k8M9H+C+fQD+uOunl+kzLdI9FcXLPOP0X9XzEdH
+KNa+McB8E/5M9V8JZ34j+fDf+MWynwG/yhV/Euh8O9tzHdn+Nuonv80HfuB
ko+12B8WIz/Z2C/GIV8fh8n+cRP5m4f9ZBDyuRP7Swjy64z9Zg7y7YP9R8n/
eexHe8EHF+xPCeDHaexXLuDLFuxfYeDPVuxnu8GnSuxvX4Bfv2G/C78ifFP2
P+HfmSn/ATVsZwQ=
       "]]}}, {{}, {}}}, 
   {PointSize[0.05], PointBox[{0, 0}]}},
  Axes->{False, False},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  Method->{
   "OptimizePlotMarkers" -> True, "OptimizePlotMarkers" -> True, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        Identity[
         Part[#, 1]], 
        Identity[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        Identity[
         Part[#, 1]], 
        Identity[
         Part[#, 2]]}& )}},
  PlotRange->{{-0.55, 0.55}, {-1.45, 1.45}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.811323175420574*^9, 3.811323291509704*^9},
 CellLabel->"Out[11]=",ExpressionUUID->"2a125c33-ee0f-4f00-9d1e-740d1810a929"]
}, Open  ]],

Cell[TextData[{
 "Now we go through exactly the same procedures again for a smaller \
eccentricity, ",
 StyleBox["e", "Input"],
 " = 0.2."
}], "Text",
 CellFrame->True,
 Background->GrayLevel[
  0.849989],ExpressionUUID->"fbf543af-86ca-4851-b28f-1bd6bf12381f"],

Cell["rotlist={};", "Input",
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"In[12]:=",ExpressionUUID->"17b16845-8741-4a5d-9dc5-5f9fce76e969"],

Cell["p=1/2; a=1.0; e=0.2;", "Input",
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"In[13]:=",ExpressionUUID->"45be0c4d-2d40-41dd-bb6b-54ce6f67b4e8"],

Cell["\<\
Do[
(posvec=position[t,a,e];
f=N[ArcTan[posvec[[1]],posvec[[2]]]];
rad=N[Sqrt[posvec[[1]]^2+posvec[[2]]^2]];
\[Theta]=p*t;
\[Psi]=\[Theta]-f;
blip=N[{rad*Cos[\[Psi]],rad*Sin[\[Psi]]}];
AppendTo[rotlist,blip];),
{t,0,4Pi,Pi/10}]\
\>", "Input",
 AspectRatioFixed->False,
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"In[14]:=",ExpressionUUID->"3203f87f-60c2-464a-82ae-5f9fcd3d7ed5"],

Cell[CellGroupData[{

Cell["\<\
points=
ListPlot[rotlist,AspectRatio->Automatic, 
PlotStyle->PointSize[0.05],Axes->None]\
\>", "Input",
 CellChangeTimes->{{3.811323191185152*^9, 3.811323193438764*^9}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"In[15]:=",ExpressionUUID->"4386805d-9dd8-4c99-96a1-15eaa9830a85"],

Cell[BoxData[
 GraphicsBox[{{}, 
   {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.05], 
    AbsoluteThickness[1.6], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQBGIQPWsmCLy0Z4CCImH1EodjL+xN0w+rXPO9sH/qOgV/
+Z5n9lcXvL+cKnN/P5NTy42uqsf28j1MwRGnnu6/d+unxlKZB/Z1N4I0y069
2n/PwfdM9Lyb9uzNbhJe697tN0mdfs634bL95i0ddasvfNgfq3Tz4tZPp+0t
TOSNjjz5uH8n68X5k74ftL9yy77SeeGn/QUe4k/Sezfaq7GvPCPF/3n/1St1
Bcd1p9oYg8Hn/cEQ+f2qUPnHEP37L0P1B0HM328JNV8XYv9+mP03Ie7bzwF1
302I+/e3QN3PCPHffgWo/6D+338D6n9o+Ow3hoYPNPz2/1t+RC68a9MemLwh
RN5+IlT/Q4h+exao+TIQ8+3vQO2vh9hvfwfqPmj42Ruiut8+CtV/9sdQ/W/f
DQ0faPjZz4hQdq3qPbAHGn72q6HhCw0/+8Oo4W8fDo0fmPlQ++23QO2Hus8e
Gn72D6DxXwt1P1r6sJ8CTT93of7Pg6YvH2j4wNIfJPwO2QAAmVJZKw==
     "]]}, {{}, {}}},
  
  Axes->{False, False},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  Method->{
   "OptimizePlotMarkers" -> True, "OptimizePlotMarkers" -> True, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        Identity[
         Part[#, 1]], 
        Identity[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        Identity[
         Part[#, 1]], 
        Identity[
         Part[#, 2]]}& )}},
  PlotRange->{{-0.8, 0.8}, {-1.2, 1.2}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.811323200814055*^9, 3.8113232917256203`*^9},
 CellLabel->"Out[15]=",ExpressionUUID->"70879f0b-c283-4b3d-8eb3-20da9d638a14"]
}, Open  ]],

Cell["rotlist = {};", "Input",
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"In[16]:=",ExpressionUUID->"3b7cfbeb-4614-4226-8221-497491349d3a"],

Cell["\<\
Do[
(posvec=position[t,a,e];
f=N[ArcTan[posvec[[1]],posvec[[2]]]];
rad=N[Sqrt[posvec[[1]]^2+posvec[[2]]^2]];
\[Theta]=p*t;
\[Psi]=\[Theta]-f;
blip=N[{rad*Cos[\[Psi]],rad*Sin[\[Psi]]}];
AppendTo[rotlist,blip];),
{t,0,4Pi,Pi/40}]\
\>", "Input",
 AspectRatioFixed->False,
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"In[17]:=",ExpressionUUID->"e541f291-e8ec-4994-b32a-b9785dd7576b"],

Cell[CellGroupData[{

Cell["\<\
curve =
ListPlot[rotlist,Joined->True,
 AspectRatio->Automatic, Axes->None]\
\>", "Input",
 CellChangeTimes->{{3.811323223015547*^9, 3.811323223598588*^9}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"In[18]:=",ExpressionUUID->"ac7f6bb7-6243-4543-a7f5-265a47e2554e"],

Cell[BoxData[
 GraphicsBox[{{}, {{}, {}, 
    {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.009166666666666668], 
     AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJxdln1UjncYx5OsOdsxbxvr1UNNmpoSMS9XszGzpdQOlZmY1qhZ63iLvOcg
MS8LxVnoJIpIcaayq9QelVjxPCmKolRoep5n3pIZXd/7j3v3Oc95/vid333/
ft/r+/1cl2buT34h5mZmZgdf/V7/Jya8flrIDM/TaQG/dI9roR7Ue+Tm7SdZ
f2FSavJ3LZS7YbT27rp83pfmWf2J5tV6xfWCwkPFHNln8CIvbTONCC10qPQu
5xFn+6bM/7qZEv3Lps5x0/GSgvem11xqosrtgaO/fXKNE3zLehg8mqhprf3n
Xfff4PiMAT72cXdJf+Dh1RCbWzzT6B/UqG+kjcET80eNqefnCbbnsvo2UmSQ
3jVMd5tXD/R0rZ3SQNZrHHYvC2xg8wkxVbHL75B9nLl/QGkjT7fRnslOuU3d
is9ZjxvcxBb6bWG2l+vp1AGfZxsjmjkncM9d30d15LViTETe4Ra+ef2ZU4pN
Ha2q8huypPQeZ/W42Dcq9iZF780aGVxznzWP7f7pVVdDeem9Wl1qH3D20MmH
ksbcoI/O7XKPv9TKN728y2b+Vk2W6yf1n5LxN9tvdp7q2b2KYo4t3vZ89UMO
6T/I8XZ0Jd3Ln7DuiKaNF2Qubb3yTEcz9FbzFkW3sUfInsvea65SVvamVenl
bezpE1+8oOcVyosesGGnnYGTS/YHW6eVU9dZzpk/fG/g5tacubMTL1NKaIU2
9IiBZw2srjhtvEijPOzdixoM3FH2xZqF35SQe7urx3FrI+tslxp2VmrJwWaf
lbe3kXtbm92yDC4i1z7LokuijHy2W0XSzicFpLtOUZ8eNHKNJlyf68lEKfce
Xys08rwS234du3NIe9S2NqneyIdKq7xaup+hY2G3vjzZbuSIyf0aQrdm0geW
R8us3jFx+tC0xo1j02ho147oVjsTfzYnKzY88iBNe1nnNtzZxObOdfWHw3ZQ
z8P1u0zDTKzXrYq44BI/dnjnY+JJQzrXWVl/W/azH/YnyPtZeb+/fJ8d8f18
OR8fx/l+lPNzEc5/Re7H43G/O3J/vor7t1t16sMu0KdY9GNH6Ncu+rKir5/o
z6Oh/1OpD6eiPvFSP+6G+jlIffkP1NdF6s9K/cPFH6z4Y7b4h+/DPy7iL14H
f1WL//hN+C9D/MnD4M9B4l9W/Jsm/ua18He1+J9j4P9cyQcT8vGG5IdPID8z
JV/cBfnqIvnjAcjfWskn90M+n0h+eQnyGyD55jjkG/nnKuR/j/CBH4APi4Qf
XA1+eAhfOAl8AX94OPiTKHziXuBTpfCLfwe/wDc2jBe+gX/8b2qR3YzYU3nt
WL8k66Ts3yv7Cfzj9+X9pHzfTb5P4B/vk/PRMpy/Qs5PibhfrdyPduD+9XJ/
CoQ+W0Qfegn9wkU/UvR9V/QlC+hvI/pToLo+ZIn6ZUj9SKnvOKkv1aD+q6X+
dAL+WCn+IHu1f+g0/OUq/qIa+A/8Iyf4c734k36Gf5vEvzQf/g4Qf5Ob2v80
DPkA/+gA8mMu+aEXyBf4R0Hq/FGbOp/0F/IL/pGF8I/BP9Kq80+N4AP4Rylq
flA5+AL+0RbwB/yjheDTh8InWg5++Qq/yOik4hvtDRg0cfnW/Dzwj5LVfCQN
+An+UYaar5QO/oJ/VAo+g38UBX7/ifPvBt+9cL9CNf/JTN0fqEzdP+gG+osH
9J2B/qPo367uT5Sq7l80GP0N/FPqT9mofyT6YyD8MUfdP6k3+utm+Av+I/CP
MtX9mRzRv3Ph30L098Xwdx36/0r4/zzmg4+Rjxc6mR9ykJ9pmC/eQr7+N39Q
FOYTDfL5CPPLCuQ3CPPNJuT7V8w/tcg/+Ecm8AH8oIvghxvmqxPgy0LMX1+B
P8p8NgJ80mF+ywe/lPnOQuY7UuY/4d/5sf8BrYlrFw==
      "]]}}, {{}, {}}},
  Axes->{False, False},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  Method->{
   "OptimizePlotMarkers" -> True, "OptimizePlotMarkers" -> True, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        Identity[
         Part[#, 1]], 
        Identity[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        Identity[
         Part[#, 1]], 
        Identity[
         Part[#, 2]]}& )}},
  PlotRange->{{-0.8, 0.8}, {-1.2, 1.2}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.811323225169546*^9, 3.811323291942134*^9},
 CellLabel->"Out[18]=",ExpressionUUID->"da9661a5-0508-44ec-ac50-d2b943ff12de"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Show[points,curve,sun]", "Input",
 CellChangeTimes->{3.8113232302991056`*^9},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"In[19]:=",ExpressionUUID->"9aebe8f6-de78-436c-ae2c-171aea299f1b"],

Cell[BoxData[
 GraphicsBox[{{{}, 
    {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.05], 
     AbsoluteThickness[1.6], PointBox[CompressedData["
1:eJxTTMoPSmViYGDQBGIQPWsmCLy0Z4CCImH1EodjL+xN0w+rXPO9sH/qOgV/
+Z5n9lcXvL+cKnN/P5NTy42uqsf28j1MwRGnnu6/d+unxlKZB/Z1N4I0y069
2n/PwfdM9Lyb9uzNbhJe697tN0mdfs634bL95i0ddasvfNgfq3Tz4tZPp+0t
TOSNjjz5uH8n68X5k74ftL9yy77SeeGn/QUe4k/Sezfaq7GvPCPF/3n/1St1
Bcd1p9oYg8Hn/cEQ+f2qUPnHEP37L0P1B0HM328JNV8XYv9+mP03Ie7bzwF1
302I+/e3QN3PCPHffgWo/6D+338D6n9o+Ow3hoYPNPz2/1t+RC68a9MemLwh
RN5+IlT/Q4h+exao+TIQ8+3vQO2vh9hvfwfqPmj42Ruiut8+CtV/9sdQ/W/f
DQ0faPjZz4hQdq3qPbAHGn72q6HhCw0/+8Oo4W8fDo0fmPlQ++23QO2Hus8e
Gn72D6DxXwt1P1r6sJ8CTT93of7Pg6YvH2j4wNIfJPwO2QAAmVJZKw==
      
      "]]}, {{}, {}}}, {{}, {{}, {}, 
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.009166666666666668],
       AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJxdln1UjncYx5OsOdsxbxvr1UNNmpoSMS9XszGzpdQOlZmY1qhZ63iLvOcg
MS8LxVnoJIpIcaayq9QelVjxPCmKolRoep5n3pIZXd/7j3v3Oc95/vid333/
ft/r+/1cl2buT34h5mZmZgdf/V7/Jya8flrIDM/TaQG/dI9roR7Ue+Tm7SdZ
f2FSavJ3LZS7YbT27rp83pfmWf2J5tV6xfWCwkPFHNln8CIvbTONCC10qPQu
5xFn+6bM/7qZEv3Lps5x0/GSgvem11xqosrtgaO/fXKNE3zLehg8mqhprf3n
Xfff4PiMAT72cXdJf+Dh1RCbWzzT6B/UqG+kjcET80eNqefnCbbnsvo2UmSQ
3jVMd5tXD/R0rZ3SQNZrHHYvC2xg8wkxVbHL75B9nLl/QGkjT7fRnslOuU3d
is9ZjxvcxBb6bWG2l+vp1AGfZxsjmjkncM9d30d15LViTETe4Ra+ef2ZU4pN
Ha2q8huypPQeZ/W42Dcq9iZF780aGVxznzWP7f7pVVdDeem9Wl1qH3D20MmH
ksbcoI/O7XKPv9TKN728y2b+Vk2W6yf1n5LxN9tvdp7q2b2KYo4t3vZ89UMO
6T/I8XZ0Jd3Ln7DuiKaNF2Qubb3yTEcz9FbzFkW3sUfInsvea65SVvamVenl
bezpE1+8oOcVyosesGGnnYGTS/YHW6eVU9dZzpk/fG/g5tacubMTL1NKaIU2
9IiBZw2srjhtvEijPOzdixoM3FH2xZqF35SQe7urx3FrI+tslxp2VmrJwWaf
lbe3kXtbm92yDC4i1z7LokuijHy2W0XSzicFpLtOUZ8eNHKNJlyf68lEKfce
Xys08rwS234du3NIe9S2NqneyIdKq7xaup+hY2G3vjzZbuSIyf0aQrdm0geW
R8us3jFx+tC0xo1j02ho147oVjsTfzYnKzY88iBNe1nnNtzZxObOdfWHw3ZQ
z8P1u0zDTKzXrYq44BI/dnjnY+JJQzrXWVl/W/azH/YnyPtZeb+/fJ8d8f18
OR8fx/l+lPNzEc5/Re7H43G/O3J/vor7t1t16sMu0KdY9GNH6Ncu+rKir5/o
z6Oh/1OpD6eiPvFSP+6G+jlIffkP1NdF6s9K/cPFH6z4Y7b4h+/DPy7iL14H
f1WL//hN+C9D/MnD4M9B4l9W/Jsm/ua18He1+J9j4P9cyQcT8vGG5IdPID8z
JV/cBfnqIvnjAcjfWskn90M+n0h+eQnyGyD55jjkG/nnKuR/j/CBH4APi4Qf
XA1+eAhfOAl8AX94OPiTKHziXuBTpfCLfwe/wDc2jBe+gX/8b2qR3YzYU3nt
WL8k66Ts3yv7Cfzj9+X9pHzfTb5P4B/vk/PRMpy/Qs5PibhfrdyPduD+9XJ/
CoQ+W0Qfegn9wkU/UvR9V/QlC+hvI/pToLo+ZIn6ZUj9SKnvOKkv1aD+q6X+
dAL+WCn+IHu1f+g0/OUq/qIa+A/8Iyf4c734k36Gf5vEvzQf/g4Qf5Ob2v80
DPkA/+gA8mMu+aEXyBf4R0Hq/FGbOp/0F/IL/pGF8I/BP9Kq80+N4AP4Rylq
flA5+AL+0RbwB/yjheDTh8InWg5++Qq/yOik4hvtDRg0cfnW/Dzwj5LVfCQN
+An+UYaar5QO/oJ/VAo+g38UBX7/ifPvBt+9cL9CNf/JTN0fqEzdP+gG+osH
9J2B/qPo367uT5Sq7l80GP0N/FPqT9mofyT6YyD8MUfdP6k3+utm+Av+I/CP
MtX9mRzRv3Ph30L098Xwdx36/0r4/zzmg4+Rjxc6mR9ykJ9pmC/eQr7+N39Q
FOYTDfL5CPPLCuQ3CPPNJuT7V8w/tcg/+Ecm8AH8oIvghxvmqxPgy0LMX1+B
P8p8NgJ80mF+ywe/lPnOQuY7UuY/4d/5sf8BrYlrFw==
       "]]}}, {{}, {}}}, 
   {PointSize[0.05], PointBox[{0, 0}]}},
  Axes->{False, False},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  Method->{
   "OptimizePlotMarkers" -> True, "OptimizePlotMarkers" -> True, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        Identity[
         Part[#, 1]], 
        Identity[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        Identity[
         Part[#, 1]], 
        Identity[
         Part[#, 2]]}& )}},
  PlotRange->{{-0.8, 0.8}, {-1.2, 1.2}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.8113232310604477`*^9, 3.8113232919485397`*^9},
 CellLabel->"Out[19]=",ExpressionUUID->"b23ff3d2-9ec6-4b9d-ad80-265f67361518"]
}, Open  ]]
},
WindowToolbars->{},
CellGrouping->Manual,
WindowSize->{918, 633},
WindowMargins->{{18, Automatic}, {Automatic, 357}},
PrivateNotebookOptions->{"VersionedStylesheet"->{"Default.nb"[8.] -> False}},
ShowCellLabel->True,
ShowCellTags->False,
FrontEndVersion->"12.1 for Mac OS X x86 (64-bit) (June 19, 2020)",
StyleDefinitions->"Default.nb",
ExpressionUUID->"6ad4399b-5075-4c07-82a7-06f2ffbf2d88"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[558, 20, 109, 0, 67, "Section",ExpressionUUID->"323a7a94-74ae-47fe-bf70-03175e2b4562"],
Cell[670, 22, 169, 3, 49, "Text",ExpressionUUID->"edf2fbdf-9d4b-4a22-8970-49a68d5ae8b9"],
Cell[842, 27, 240, 4, 30, "Input",ExpressionUUID->"4bb167c8-34fc-47f4-b925-f9541dac110a"],
Cell[1085, 33, 462, 16, 76, "Text",ExpressionUUID->"68683205-1ab7-4cc9-b22b-f479724cb4e4"],
Cell[1550, 51, 209, 3, 30, "Input",ExpressionUUID->"d1686b74-31ec-40e4-83b2-fbc8229bce7f"],
Cell[1762, 56, 261, 8, 84, "Input",ExpressionUUID->"93ff1937-30ca-4c36-9971-37e5d62339b4"],
Cell[2026, 66, 267, 7, 53, "Text",ExpressionUUID->"3833d889-e0a5-48d1-9805-10d9d811979d"],
Cell[2296, 75, 138, 2, 30, "Input",ExpressionUUID->"03983051-090a-40f2-a095-6721e57f302b"],
Cell[2437, 79, 298, 9, 53, "Text",ExpressionUUID->"a3925c35-3aee-4f0e-aedf-fe61a58b9384"],
Cell[2738, 90, 148, 2, 30, "Input",ExpressionUUID->"f0f007a0-3ea4-45bf-909d-ebc2a91aa0f8"],
Cell[2889, 94, 309, 8, 76, "Text",ExpressionUUID->"3c78e65f-97f1-4cc7-b96d-9f75161d5094"],
Cell[3201, 104, 388, 13, 174, "Input",ExpressionUUID->"5a5f813c-a547-4e6f-b415-76a71e2b210c"],
Cell[3592, 119, 152, 3, 53, "Text",ExpressionUUID->"8414c6b9-3e43-460b-9c16-2783dba83253"],
Cell[CellGroupData[{
Cell[3769, 126, 289, 7, 66, "Input",ExpressionUUID->"d1fad859-b08d-4a65-8f64-0da2a7427869"],
Cell[4061, 135, 1789, 46, 449, "Output",ExpressionUUID->"4a6151f4-33f5-42b3-9286-5df929df066f"]
}, Open  ]],
Cell[5865, 184, 329, 8, 76, "Text",ExpressionUUID->"e8545e6a-1627-4e25-bf3a-728cf926a47c"],
Cell[6197, 194, 140, 2, 30, "Input",ExpressionUUID->"36a73641-7856-4644-8d7c-81278919c504"],
Cell[6340, 198, 157, 3, 53, "Text",ExpressionUUID->"760c4a33-de0e-44f3-9c41-d2b753070faf"],
Cell[6500, 203, 388, 13, 174, "Input",ExpressionUUID->"721b9631-d25d-486a-9edc-406ce1e0f04c"],
Cell[6891, 218, 144, 3, 53, "Text",ExpressionUUID->"31c476c0-5976-4e30-b16c-1573820c02a3"],
Cell[CellGroupData[{
Cell[7060, 225, 215, 6, 66, "Input",ExpressionUUID->"1172eeff-6f38-4a63-9403-43d4f496defa"],
Cell[7278, 233, 3205, 68, 449, "Output",ExpressionUUID->"9692a423-16f7-46e1-8869-ceaf9c98fbd3"]
}, Open  ]],
Cell[10498, 304, 185, 3, 53, "Text",ExpressionUUID->"ee164c14-36fd-49b1-80a6-3cd912011d8b"],
Cell[CellGroupData[{
Cell[10708, 311, 192, 3, 30, "Input",ExpressionUUID->"d52923cb-3730-4958-9696-93bd3884208a"],
Cell[10903, 316, 3954, 82, 449, "Output",ExpressionUUID->"2a125c33-ee0f-4f00-9d1e-740d1810a929"]
}, Open  ]],
Cell[14872, 401, 260, 8, 53, "Text",ExpressionUUID->"fbf543af-86ca-4851-b28f-1bd6bf12381f"],
Cell[15135, 411, 139, 2, 30, "Input",ExpressionUUID->"17b16845-8741-4a5d-9dc5-5f9fce76e969"],
Cell[15277, 415, 148, 2, 30, "Input",ExpressionUUID->"45be0c4d-2d40-41dd-bb6b-54ce6f67b4e8"],
Cell[15428, 419, 389, 13, 174, "Input",ExpressionUUID->"3203f87f-60c2-464a-82ae-5f9fcd3d7ed5"],
Cell[CellGroupData[{
Cell[15842, 436, 290, 7, 66, "Input",ExpressionUUID->"4386805d-9dd8-4c99-96a1-15eaa9830a85"],
Cell[16135, 445, 1754, 45, 449, "Output",ExpressionUUID->"70879f0b-c283-4b3d-8eb3-20da9d638a14"]
}, Open  ]],
Cell[17904, 493, 141, 2, 30, "Input",ExpressionUUID->"3b7cfbeb-4614-4226-8221-497491349d3a"],
Cell[18048, 497, 389, 13, 174, "Input",ExpressionUUID->"e541f291-e8ec-4994-b32a-b9785dd7576b"],
Cell[CellGroupData[{
Cell[18462, 514, 277, 7, 66, "Input",ExpressionUUID->"ac7f6bb7-6243-4543-a7f5-265a47e2554e"],
Cell[18742, 523, 3168, 67, 449, "Output",ExpressionUUID->"da9661a5-0508-44ec-ac50-d2b943ff12de"]
}, Open  ]],
Cell[CellGroupData[{
Cell[21947, 595, 194, 3, 30, "Input",ExpressionUUID->"9aebe8f6-de78-436c-ae2c-171aea299f1b"],
Cell[22144, 600, 3919, 81, 472, "Output",ExpressionUUID->"b23ff3d2-9ec6-4b9d-ad80-265f67361518"]
}, Open  ]]
}
]
*)

(* End of internal cache information *)

